@@ -16,10 +16,8 @@
 #'
 #' If the data were obtained from an adaptive dose-finding design and you seek to estimate a dose other than the experiment's target, note that away from the target the estimates are likely biased (Flournoy and Oron, 2019). Use \code{adaptiveShrink=TRUE} to mitigate the bias. In addition, either provide the true target as \code{starget}, or a vector of values to \code{target}, with the first value being the true target.
 #' 
-#' Tie-breaking - the `tiemeth` argument passed on as the `ties` argument for `approx()` - provides yet another complication: as of 2.5.0, the default is `"decide"`, which means that the function chooses the most interior `x` value if `target` falls on the boundary of `y` estimates. Inside the boundaries the argument becomes `mean`, but with CIR this is generally ignored because there are no interior ties. Otherwise, if traditional isotonic regression (\code{\link{oldPAVA}}) is used, then the `"decide"` algorithm will pass `ties = "ordered"` on to `approx()`, respecting IR's flat stretches. A user-chosen value for `tiemeth` will override all of that; see `?approx` for options.
+#' Tie-breaking - the `tiemeth` argument passed on as the `ties` argument for `approx()` - provides yet another complication: as of 2.5.0, the default is `"decide"`, which means `"ordered"` - unless `target` falls on the boundary of `y` estimates, in which case the most interior `x` value is chosen. A user-chosen value for `tiemeth` will override all of that; see `?approx` for options.
 
-
- 
 ##' @author Assaf P. Oron \code{<assaf.oron.at.gmail.com>}
 
 #' @param y  can be either of the following: y values (response rates), a 2-column matrix with positive/negative response counts by dose, a \code{\link{DRtrace}} object or a \code{\link{doseResponse}} object. 
@@ -51,7 +49,7 @@
 
 #' @export
 
-doseFind<-function(y,x=NULL,wt=NULL,estfun=cirPAVA,target=NULL,full=FALSE, dec=FALSE, extrapolate=FALSE,errOnFlat=FALSE, adaptiveShrink=FALSE, starget=target[1], tiemeth = "decide", ...) {
+doseFind<-function(y,x=NULL,wt=NULL,estfun=cirPAVA,target=NULL,full=FALSE, dec=FALSE, extrapolate=FALSE,errOnFlat=FALSE, adaptiveShrink=FALSE, starget=target[1], tiemeth = "ordered", ...) {
 
 
 ### converting to doseResponse object 
@@ -79,16 +77,12 @@ if(min(newy)==max(newy))
 ### New for 2.5.0! Context-sensitive ties method
 if(tiemeth == 'decide')
 {
-  tiemeth = mean # safe-ish default
-  # Old PAVA override
-  if(identical(estfun, oldPAVA)) tiemeth = "ordered"
-  # boundary behavior under both methods
+  tiemeth = "ordered" # safe-ish default
+  # target-on-boundary behavior under both methods
   if(max(newy) == target) tiemeth = min
   if(min(newy) == target) tiemeth = max
-
 }
 
-
 ### The estimate is generated by using 'approx' with x and y interchanged
 #return(pavout)
 tout=approx(x=newy, y=newx, xout=target, ties=tiemeth, rule=1)$y
